Package: IHWpaper
Title: Reproduce figures in IHW paper
Version: 1.40.0
Authors@R: person("Nikos", "Ignatiadis", email =
        "nikos.ignatiadis01@gmail.com", role = c("aut", "cre"))
Description: This package conveniently wraps all functions needed to
        reproduce the figures in the IHW paper (https://www.nature.com/articles/nmeth.3885) and the data 
        analysis in https://rss.onlinelibrary.wiley.com/doi/10.1111/rssb.12411,
        cf. the arXiv preprint (http://arxiv.org/abs/1701.05179). Thus
        it is a companion package to the Bioconductor IHW package.
Depends: R (>= 3.3), IHW
License: Artistic-2.0
LinkingTo: Rcpp
Imports: Rcpp, stats, splines, methods, utils, DESeq2,
        SummarizedExperiment, fdrtool, genefilter, qvalue, Biobase,
        BiocGenerics, BiocParallel, dplyr, grid, ggplot2, cowplot
VignetteBuilder: knitr
biocViews: ReproducibleResearch, ExperimentData, RNASeqData,
        ExpressionData
RoxygenNote: 7.1.2
Suggests: testthat, RColorBrewer, wesanderson, scales, gridExtra,
        BiocStyle, knitr, rmarkdown, airway, locfdr, tidyr, latex2exp
NeedsCompilation: yes
Author: Nikos Ignatiadis [aut, cre]
Maintainer: Nikos Ignatiadis <nikos.ignatiadis01@gmail.com>
git_url: https://git.bioconductor.org/packages/IHWpaper
git_branch: RELEASE_3_23
git_last_commit: 8a1ff48
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
Packaged: 2026-05-05 15:29:12 UTC; biocbuild
