# IHWpaper

This is a package which reproduces all IHW paper figures (as well as some additional figures for presentations etc.). The package is available on [Bioconductor](http://bioconductor.org/packages/release/data/experiment/html/IHWpaper.html).


# Installing the package and reproducing all simulations

You can install the package as follows:

```{r}
# install FDRreg (at specific version used for simulations here)
install_github(repo= "jgscott/FDRreg", subdir="R_pkg/", ref = "a63cebae6faecb1fb0ebee634195296f39faa11b")
# Use Bioconductor to install IHWpaper
if (!requireNamespace("BiocManager", quietly=TRUE))
    install.packages("BiocManager")
BiocManager::install("IHWpaper")
```

Afterwards you can view the pre-built vignettes or rebuild them yourself.

Notice that the vignettes load binary .Rds files which are stored in `inst/real_data_examples/result_files`
and `inst/simulations_benchmarks/result_files`. These have been generated by longer lasting jobs, the code for which can be found in `inst/real_data_examples` and `inst/simulation_benchmarks`.

