# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

ddhf_order <- function(sorted_p, filterorder, alpha) {
    .Call(`_IHWpaper_ddhf_order`, sorted_p, filterorder, alpha)
}

